/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_OS_PROCESS_HPP
#define XCSOAR_OS_PROCESS_HPP

#ifdef HAVE_POSIX

/**
 * Launch a child process but don't wait for it to exit.
 */
bool
Start(const char *const*argv);

template<typename... Args>
static inline bool
Start(const char *path, Args... args)
{
  const char *const argv[]{path, args...};
  return Start(argv);
}

/**
 * Launch a child process and wait for it to exit.
 */
bool
Run(const char *const*argv);

template<typename... Args>
static inline bool
Run(const char *path, Args... args)
{
  const char *const argv[]{path, args...};
  return Run(argv);
}

#endif

#endif
